[Pkg-ocaml-maint-commits] r5169 - /trunk/tools/gen-binNMU-request/gen-binNMU-request.py

glondu-guest at users.alioth.debian.org glondu-guest at users.alioth.debian.org
Mon Feb 11 15:41:57 UTC 2008


Author: glondu-guest
Date: Mon Feb 11 15:41:57 2008
New Revision: 5169

URL: http://svn.debian.org/wsvn/?sc=1&rev=5169
Log:
 * dep-wait lines should mention binary packages
 * fixing binary version numbers (+b1 instead of +1)

Modified:
    trunk/tools/gen-binNMU-request/gen-binNMU-request.py

Modified: trunk/tools/gen-binNMU-request/gen-binNMU-request.py
URL: http://svn.debian.org/wsvn/trunk/tools/gen-binNMU-request/gen-binNMU-request.py?rev=5169&op=diff
==============================================================================
--- trunk/tools/gen-binNMU-request/gen-binNMU-request.py (original)
+++ trunk/tools/gen-binNMU-request/gen-binNMU-request.py Mon Feb 11 15:41:57 2008
@@ -26,12 +26,15 @@
         return int(max(x))+1
 
 def rmadison(pkg):
     """Returns a triple source_version, numNMU, archs"""
     r = getoutput("rmadison -s unstable -S %s" % pkg)
     source_version = "0"
     numNMU = 0
     archs = []
+    binary_package = pkg
     for x in filter(None, r.split("\n")):
+        if "i386" in x:
+            binary_package = madep.split(x.strip())[0]
         y = x.replace("all", "alpha, amd64, arm, armel, hppa, i386, ia64, m68k, mips, mipsel, powerpc, s390, sparc")
         l = madep.split(y.strip())
         version = l[1]
@@ -44,7 +47,7 @@
             if arch == "source" and version_compare(version, source_version) > 0:
                 source_version = version
     if numNMU:
-        return source_version, numNMU, archs
+        return source_version, numNMU, binary_package, archs
     else:
         return None
 
@@ -69,11 +72,11 @@
     for pkg, deps in pkg_list:
         x = rmadison(pkg)
         if not x: continue
-        source_version, numNMU, archs = x
+        source_version, numNMU, binary_package, archs = x
         print "%s_%s, Rebuild with ocaml 3.10.1, %d, %s" % \
           (pkg, source_version, numNMU, " ".join(archs))
         for dep in deps:
-            dep_ver = next_dict.get(dep)
+            binpkg, dep_ver = next_dict.get(dep, (None, None))
             if dep_ver:
-                print "%s dep-wait %s (>= %s)" % (pkg, dep, dep_ver)
-        next_dict[pkg] = source_version + "+%d" % numNMU
+                print "%s dep-wait %s (>= %s)" % (pkg, binpkg, dep_ver)
+        next_dict[pkg] = (binary_package, source_version + "+b%d" % numNMU)
@@ -26,12 +26,15 @@
 
 def rmadison(pkg):
-    """Returns a triple source_version, numNMU, archs"""
+    """Returns a triple source_version, numNMU, binary_package, archs"""
     r = getoutput("rmadison -s unstable -S %s" % pkg)
     source_version = "0"




More information about the Pkg-ocaml-maint-commits mailing list